Changelog
=========


(unreleased)
------------

New
~~~
- Supported_languages call. [Renaud Canarduck]
- Api_version. [Renaud Canarduck]

Fix
~~~
- Dev Gitlab CI. [Renaud Canarduck]

Other
~~~~~
- Dev: pkg: messing with bumpversion. [Renaud Canarduck]


